==> download.php?FileName=terralib-5.3.0.zip: packages/windows/terralib.conf.cmake <==
#
#  Copyright (C) 2008-2014 National Institute For Space Research (INPE) - Brazil.
#
#  This file is part of the TerraLib - a Framework for building GIS enabled applications.
#
#  TerraLib is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published by
#  the Free Software Foundation, either version 3 of the License,
#  or (at your option) any later version.
#
#  TerraLib is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with TerraLib. See COPYING. If not, write to
#  TerraLib Team at <terralib-team@terralib.org>.
#
#  Description: TerraLib CMake cache options for building TerraLib on Windows environments.
#
#  Before start, please read the "PACKAGE-INSTRUCTIONS".
#

# Define CMake variables:
set (CMAKE_INSTALL_PREFIX "$ENV{TERRALIB_INSTALL_PATH}/" CACHE PATH "Where to install TerraLib?" FORCE)
set (CMAKE_INSTALL_RPATH "$ENV{TERRALIB_INSTALL_PATH}/lib" CACHE PATH "Where to install TerraLib libs?" FORCE)
set (CMAKE_PREFIX_PATH "$ENV{TERRALIB_DEPENDENCIES_DIR};$ENV{TERRALIB_DEPENDENCIES_DIR}/lib;$ENV{TERRALIB_DEPENDENCIES_DIR}/swig" CACHE PATH "Where to find libraries?" FORCE)
set (terralib4_DIR "$ENV{TERRALIB_DEPENDENCIES_DIR}/lib/cmake/terralib-4.2.2" CACHE PATH "Where to find TerraLib4 libraries?" FORCE)

# Turn off TerraLib CMake variables:
set (TERRALIB_DOXYGEN_ENABLED OFF CACHE BOOL "Use Doxygen?" FORCE)
set (TERRALIB_BUILD_EXAMPLES_ENABLED OFF CACHE BOOL "Build Examples?" FORCE)
set (TERRALIB_BUILD_UNITTEST_ENABLED OFF CACHE BOOL "Build Unittests?" FORCE)
set (TERRALIB_MOD_BINDING_LUA_ENABLED OFF CACHE BOOL "Build binding Lua?" FORCE)
set (TERRALIB_MOD_BINDING_JAVA_ENABLED OFF CACHE BOOL "Build binding Java?" FORCE)
set (TERRALIB_MOD_VM_LUA_ENABLED OFF CACHE BOOL "Build Lua Virtual Machine plugin?" FORCE)

# Turn on TerraLib CMake variables:
set (TERRALIB_BUILD_AS_BUNDLE ON CACHE BOOL "Build As Bundle?" FORCE)
set (TERRALIB_TRACK_3RDPARTY_DEPENDENCIES ON CACHE BOOL "Build with T3P?" FORCE)
set (TERRALIB_MOD_EDIT_CORE_ENABLED ON CACHE BOOL "Build Edit?" FORCE)
set (TERRALIB_MOD_QT_PLUGINS_WTSS_ENABLED ON CACHE BOOL "Build Wtss-Cxx?" FORCE)
set (TERRALIB_QHELP_ENABLED ON CACHE BOOL "Build Qhelp?" FORCE)
set (TERRALIB_MOD_CEDITOR_ENABLED ON CACHE BOOL "Build CEditor plugin?" FORCE)
set (TERRALIB_MOD_BINDING_PYTHON_ENABLED ON CACHE BOOL "Build binding Python?" FORCE)
set (TERRALIB_MOD_VM_ENABLED ON CACHE BOOL "Build Virtual Machine module?" FORCE)
set (TERRALIB_MOD_VM_PYTHON_ENABLED ON CACHE BOOL "Build Python Virtual Machine plugin?" FORCE)

# Set the package type to be generated:
set (CPACK_BINARY_NSIS ON CACHE BOOL "Generate DEB?" FORCE)
set (CPACK_SOURCE_7Z OFF CACHE BOOL "Generate STGZ?" FORCE)
set (CPACK_SOURCE_ZIP OFF CACHE BOOL "Generate TGZ?" FORCE)

==> download.php?FileName=terralib-5.3.2.zip: packages/windows/terralib.conf.cmake <==
#
#  Copyright (C) 2008-2014 National Institute For Space Research (INPE) - Brazil.
#
#  This file is part of the TerraLib - a Framework for building GIS enabled applications.
#
#  TerraLib is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published by
#  the Free Software Foundation, either version 3 of the License,
#  or (at your option) any later version.
#
#  TerraLib is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with TerraLib. See COPYING. If not, write to
#  TerraLib Team at <terralib-team@terralib.org>.
#
#  Description: TerraLib CMake cache options for building TerraLib on Windows environments.
#
#  Before start, please read the "PACKAGE-INSTRUCTIONS".
#

# Define CMake variables:
set (CMAKE_INSTALL_PREFIX "$ENV{TERRALIB_INSTALL_PATH}/" CACHE PATH "Where to install TerraLib?" FORCE)
set (CMAKE_INSTALL_RPATH "$ENV{TERRALIB_INSTALL_PATH}/lib" CACHE PATH "Where to install TerraLib libs?" FORCE)
set (CMAKE_PREFIX_PATH "$ENV{TERRALIB_DEPENDENCIES_DIR};$ENV{TERRALIB_DEPENDENCIES_DIR}/lib;$ENV{TERRALIB_DEPENDENCIES_DIR}/swig;$ENV{TERRAPRINT_DIR}" CACHE PATH "Where to find libraries?" FORCE)
set (terralib4_DIR "$ENV{TERRALIB_DEPENDENCIES_DIR}/lib/cmake/terralib-4.2.2" CACHE PATH "Where to find TerraLib4 libraries?" FORCE)
#set (terralib_layout_DIR "$ENV{TERRAPRINT_DIR}" CACHE PATH "Where to find TerraPrint libraries?" FORCE)

# Turn off TerraLib CMake variables:
set (TERRALIB_DOXYGEN_ENABLED OFF CACHE BOOL "Use Doxygen?" FORCE)
set (TERRALIB_BUILD_EXAMPLES_ENABLED OFF CACHE BOOL "Build Examples?" FORCE)
set (TERRALIB_BUILD_UNITTEST_ENABLED OFF CACHE BOOL "Build Unittests?" FORCE)
set (TERRALIB_MOD_BINDING_LUA_ENABLED OFF CACHE BOOL "Build binding Lua?" FORCE)
set (TERRALIB_MOD_BINDING_JAVA_ENABLED OFF CACHE BOOL "Build binding Java?" FORCE)
set (TERRALIB_MOD_VM_LUA_ENABLED OFF CACHE BOOL "Build Lua Virtual Machine plugin?" FORCE)

# Turn on TerraLib CMake variables:
set (TERRALIB_BUILD_AS_BUNDLE ON CACHE BOOL "Build As Bundle?" FORCE)
set (TERRALIB_TRACK_3RDPARTY_DEPENDENCIES ON CACHE BOOL "Build with T3P?" FORCE)
set (TERRALIB_MOD_EDIT_CORE_ENABLED ON CACHE BOOL "Build Edit?" FORCE)
set (TERRALIB_MOD_QT_PLUGINS_WTSS_ENABLED ON CACHE BOOL "Build Wtss-Cxx?" FORCE)
set (TERRALIB_QHELP_ENABLED ON CACHE BOOL "Build Qhelp?" FORCE)
set (TERRALIB_MOD_CEDITOR_ENABLED ON CACHE BOOL "Build CEditor plugin?" FORCE)
set (TERRALIB_MOD_BINDING_PYTHON_ENABLED ON CACHE BOOL "Build binding Python?" FORCE)
set (TERRALIB_MOD_VM_ENABLED ON CACHE BOOL "Build Virtual Machine module?" FORCE)
set (TERRALIB_MOD_VM_PYTHON_ENABLED ON CACHE BOOL "Build Python Virtual Machine plugin?" FORCE)

# Set the package type to be generated:
set (CPACK_BINARY_NSIS ON CACHE BOOL "Generate DEB?" FORCE)
set (CPACK_SOURCE_7Z OFF CACHE BOOL "Generate STGZ?" FORCE)
set (CPACK_SOURCE_ZIP OFF CACHE BOOL "Generate TGZ?" FORCE)
